@@ -22,15 +22,15 @@
 
 #include <glib/gi18n.h>
 #include <gio/gio.h>
-#include <glade/glade-xml.h>
 #include <libanjuta/anjuta-debug.h>
 #include <libanjuta/anjuta-shell.h>
+#include <libanjuta/anjuta-utils.h>
 #include <string.h>
 
 /* Constants
  *---------------------------------------------------------------------------*/
 
-#define GLADE_FILE PACKAGE_DATA_DIR"/glade/anjuta-build-basic-autotools-plugin.glade"
+#define BUILDER_FILE PACKAGE_DATA_DIR"/glade/anjuta-build-basic-autotools-plugin.ui"
 
 #define CONFIGURE_DIALOG "configure_dialog"
 #define RUN_AUTOGEN_CHECK "force_autogen_check"
@@ -197,9 +197,8 @@ build_gtk_file_chooser_create_and_set_uri (GtkFileChooser *chooser, const gchar
 		g_error_free (error);
 	}
 	g_object_unref (dir);
-
-	gtk_file_chooser_set_current_folder_uri (chooser, uri);
-	return gtk_file_chooser_set_uri (chooser, uri);
+	
+	return gtk_file_chooser_set_current_folder_uri (chooser, uri);
 }
 
 /* Do not delete the automatically created folder */
@@ -306,20 +305,23 @@ fill_dialog (BuildConfigureDialog *dlg)
 gboolean
 build_dialog_configure (GtkWindow* parent, const gchar *project_root_uri, BuildConfigurationList *config_list, gboolean *run_autogen)
 {
-	GladeXML* gxml;
+	GtkBuilder* bxml;
 	BuildConfigureDialog dlg;
 	BuildConfiguration *cfg = NULL;
 	gint response;
 	
 	/* Get all dialog widgets */
-	gxml = glade_xml_new (GLADE_FILE, CONFIGURE_DIALOG, NULL);
-	dlg.win = glade_xml_get_widget (gxml, CONFIGURE_DIALOG);
-	dlg.combo = glade_xml_get_widget(gxml, CONFIGURATION_COMBO);
-	dlg.autogen = glade_xml_get_widget(gxml, RUN_AUTOGEN_CHECK);
-	dlg.build_dir_chooser = glade_xml_get_widget(gxml, BUILD_DIR_CHOOSER);
-	dlg.args = glade_xml_get_widget(gxml, CONFIGURE_ARGS_ENTRY);
-	dlg.ok = glade_xml_get_widget(gxml, OK_BUTTON);
-	g_object_unref (gxml);
+	bxml = anjuta_util_builder_new (BUILDER_FILE, NULL);
+	if (bxml == NULL) return FALSE;
+	anjuta_util_builder_get_objects (bxml,
+	    CONFIGURE_DIALOG, &dlg.win,
+	    CONFIGURATION_COMBO, &dlg.combo,
+	    RUN_AUTOGEN_CHECK, &dlg.autogen,
+	    BUILD_DIR_CHOOSER, &dlg.build_dir_chooser,
+	    CONFIGURE_ARGS_ENTRY, &dlg.args,
+	    OK_BUTTON, &dlg.ok,
+	    NULL);
+	g_object_unref (bxml);
 	
 	dlg.config_list = config_list;
 	dlg.project_uri = project_root_uri;
